#!/bin/bash
#
#########################################################################################
#
# Program Name: L2P_clean.sh
#
# Purpose: Clean L2P input files -- move the old L2P input files to directory $L2P_OLDIN
#
# Usage:  L2P_clean.sh $1
#    $1: A SST area number, such as 182, 162,..
#
# Called by: proc_msg.sh
#
# Scripts called: set_app_env.sh
#
# Program called: makeGHRSST-level2p.x
#
#
# Change History:
#     Mar. 2009    M. Fan  (PSGS)
#                  Modified from procCrtmB_L2P_test.sh 
#
#########################################################################################
#

doecho() { echo $@ ; eval $@ ; }

#LOGDIR=$HOME/mcidas/logs
#while getopts l: optionName
#do
#            case $optionName in
#            l)   logname="$OPTARG"
#                 datestring=`date -u +%j.%H%M` 
#                 logname="$logname.$datestring.log"
#                 export   LOGFILE=$LOGDIR/$logname
#                 exec >> $LOGFILE   2>&1 ;;
#            ?)   echo "Usage: $0  -l logfile_name \n";;
#           esac
#done

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# set log file:
#--------------
datestring=`date -u +%j`
logname=$(echo $scriptname | sed s/\.sh$// )
logname="$logname.$datestring.log"
LOGFILE=$LOGDIR/$logname
exec >> $LOGFILE   2>&1

## Usage Prompt 
#-----------------------
if [ $# -ne 1 ]
then
    echo "USAGE:    $scriptname  $1 "
    echo 'e.g.      $scriptname  142 '
    exit -1
fi

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo "`date -u` start $scriptname"              # time stamp

echo  "L2P_DATA   = $L2P_DATA"
echo  "L2P_OUTDIR = $L2P_OUTDIR"
echo  "L2P_INDIR  = $L2P_INDIR"
echo  "L2P_OLDIN  = $L2P_OLDIN"

## get SST AREA:
#---------------
IAREA=0$1
echo " SST AREA is: $IAREA"



##  Clear out old L2P input files 
#--------------------------------
cd ${L2P_INDIR}
 
HFILE=L2P.$IAREA.header
NFILE=L2P.$IAREA.nav
DFILE=L2P.$IAREA.data
ls -l |grep $IAREA
if [ -f  $HFILE ]
then
### timetag=$( od -t d4 -j12 -N8  $HFILE |head -1|awk '{print $2"-"$3/100}')
  timetag=$( od -t d4 -j12 -N8  $HFILE |head -1|awk '{printf "%3.3d-%4.4d",  $2,$3/100}')
  mv $HFILE  ${L2P_OLDIN}/$HFILE.$timetag
  mv $NFILE  ${L2P_OLDIN}/$NFILE.$timetag
  mv $DFILE  ${L2P_OLDIN}/$DFILE.$timetag
else
  rm -f $HFILE $NFILE $DFILE 2>/dev/null
fi
 
find  ${L2P_OLDIN} -type f -mtime +1 |grep 'L2P.0' |xargs -i rm {}
 
cd $MCDATDIR
