#!/bin/bash
#
#########################################################################################
#
# Program Name: buoyMatch_msg.sh
#
# Purpose: generate buoy matchup, the distribute to server
#          -- HH buoy data comes at HH:50
#
# Usage: buoyMatch_msg.sh   [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script start to run.
#
# Prerequisite: The corresponding Bayesian SST processing has beed finished
#               Current hour AREA files: 171, 0182, 1182, 2182 , 
#                            GRID files: 1820, 1821, and 
#                            buoy obs:   buoysst.hh 
#               are avaiable 
#
# Scripts called:
#           1. set_app_env.sh
#           2. sendBuoyMatch_msg.sh
#           3. set_server_Ops.sh, set_server_Test.sh, or set_server_Backup.sh by sendBuoyMatch_msg.sh
#
# Program called:  buoy_cpo_msg.k
#
# Change History:
#   09/02/27  M. Fan  (PSGS) -- Modified from proc_msg.sh and sendBuoyMatch_msg.dist1.sh
#
#######################################################################################

Proc_num=71

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

buoydata_name=buoydata.msg.${Proc_num}
buoy_program=buoy_cpo_msg_26prms.k
match_string=match_msg_

table=$SCRIPTDIR/PROC.TABLE
RegName=MSG
RegInfo=$( grep -ve ^# $table | grep -e $RegName )
isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
isBackup=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $3}' )


# set AREA files
#----------------
out_area=182
grid_0=${out_area}0


# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#---------------------------------------------------------------
 while getopts l: optionName
 do
             case $optionName in
             l)   logname="$OPTARG"
                  datestring=`date -u +%Y%m%d.%j.%H%M` 
                  logname="$logname.$datestring.log"
                  export   LOGFILE=$LOGDIR/$logname
                  exec >> $LOGFILE   2>&1 ;;
             ?)   echo "Usage: $scriptname  -l logfile_name \n";;
            esac
 done

#
echo "Begin $scriptname $* at $(date)"

## goto the directory where buoy match program will run 
#------------------------------------------------------
cd $BUOYDIR

## Get time reference from arguments
#-----------------------------------
now_hh=$(date -u +%H)
now_mm=$(date -u +%M)
send_date=$(  date -u +%Y%j )
send_hour=$(  date -u +%H )
  imglist.k LD/A.$out_area
  string182="$( imglist.k LD/A.$out_area |grep $out_area |head -1 )"
  out_cyd="20$( echo $string182 | awk '{print $5}')"
  out_hhmm="$(     echo $string182 | awk '{print $6}'|cut -c1-5)"
  out_hh="$(       echo $string182 | awk '{print $6}'|cut -c1-2)"
  out_mm="$(       echo $string182 | awk '{print $6}'|cut -c4-5)"


## Check whether buoy obs are available yet (arrive about HH:50)
#  If not ready, then wait. Otherwise put buoy data to file $buoydata
#---------------------------------------------------------------------
    if [ $now_hh -eq $out_hh ] && [ $now_mm -lt  53 ]
    then
       echo " Buoy data not yet ready - now is $out_hh:$now_mm - waiting until $out_hh:52 "
       let sleepminutes=52-$now_mm
       let sleepseconds=60*$sleepminutes
       doecho sleep $sleepseconds
    fi 

## Check if image is the expected one
#  If not, exit 
#------------------------------------
  if [ $now_hh -ne $out_hh ]; then
     echo "Expected Image Does Not Exist -- Exit the Program"
     exit
  fi
 
#  buoy matchup: for msg do'nt need composite buoydata file
#---------------------------------------------------------
    ls -la $MCDATDIR/buoysst.$out_hh
    echo "$MCDATDIR/buoysst.$out_hh  > $buoydata_name"
    cat  $MCDATDIR/buoysst.$out_hh  > $buoydata_name


## perform buoy matchup
#-------------------------
           DATESTRING="   DATE=$out_cyd   HOUR=$out_hh  $out_mm"
     echo " $buoy_program    $DATESTRING GRID=${grid_0} PROC_NUMBER=${Proc_num} "
            $buoy_program    $DATESTRING GRID=${grid_0} PROC_NUMBER=${Proc_num}


## Creat datestring for buoy match name
#-----------
year=` echo  ${send_date} |cut -c1-4 `
day=`  echo  ${send_date} |cut -c5-7 `
datestring="${year}_${day}.${send_hour}" 


### File names: buoy match results
##-------------
nameB=${match_string}${datestring}'B'
nameS=${match_string}${datestring}'S'
ls -l $BUOYDIR/$nameB
ls -l ${BUOYDIR}/$nameS

if [ -s $BUOYDIR/$nameB ]; then
     echo "buoy matchup generate SUCCESS"

#    --- send buoy matchups to product server
     send_date_string=${year}_${day}_${send_hour}
     echo "isOps = $isOps"       |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_msg.sh  $send_date_string  isOps
     echo "isTest = $isTest"     |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_msg.sh  $send_date_string  isTest
     echo "isBackup = $isBackup" |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_msg.sh  $send_date_string  isBackup
# Send for Jon Mittaz's validation into for_jon dir
#     echo "isTest = $isTest"     |grep TRUE   && doecho  $SCRIPTDIR/Manual_sendBuoyMatch_msg.sh  $send_date_string  isTest

else
    echo "buoy matchup generate FAIL"
fi   

echo " End $scriptname at $(date) "

