#!/bin/bash
#***************************************************************
#
# Script name: clean_l2p.sh
#
# Usage: clean_l2p.sh
#
# Purpose:     keep L2P data directories from unbounded growth
#              
# Written by:  Bob  2006Mar24
#
# 05/28/29  M. Fan (PSGS) -- modified to include set_app_env.sh
#
#***************************************************************
#

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# Set up the logfile

    while getopts l: optionName
    do
          case $optionName in
          l)   filename="$OPTARG"
#              datestring=`date +%j%H`
               datestring=`date +%j`
               filename="${filename}.${datestring}"
               exec >> $LOGDIR/$filename 2>&1 ;;
          ?)   echo "Usage: $0 -l logfile_name \n";;
          esac
    done
#------------------------------------------------------------------
#

#L2PData=/data/$(whoami)/L2P
L2PData=$L2P_DATA

cd $L2PData

# HighRes ncep sst


echo "===================================================="
echo " Execute $0 at $(date -u)"



echo " Cleaning  $L2PData/rtg"
find  ./rtg           -type f  -mtime +5 -ls |grep "rtg_sst"
find  ./rtg           -type f  -mtime +5     |grep "rtg_sst" |xargs -i rm {}

# Model data - gfs grib data
echo " Cleaning  $L2PData/ncep"
find  ./ncep          -type f  -mmin +1440  -ls |grep "gfs.t"  
find  ./ncep          -type f  -mmin +1440      |grep "gfs.t"   |xargs -i rm {}

# Model data  preprocessed to grid
echo " Cleaning  $L2PData/work"
find  ./work          -type f  -mmin +2880  -ls |grep "gfs.t"  
find  ./work          -type f  -mmin +2880      |grep "gfs.t"   |xargs -i rm {}

# Results
echo " Cleaning  $L2PData/netcdf_output"   
find  ./netcdf_output -type f  -mmin +120  -ls |grep "OSDPD" 
find  ./netcdf_output -type f  -mmin +120      |grep "OSDPD"  |xargs -i rm {}

#echo " Cleaning  $L2PData/netcdf_sent"
echo " Cleaning  $L2P_SENTDIR"
#find  ./netcdf_sent   -type f  -amin +240 -ls |grep "OSDPD" 
#find  ./netcdf_sent   -type f  -amin +240     |grep "OSDPD"  |xargs -i rm {}
#find  ./netcdf_sent   -type f  -mtime +0      |grep "OSDPD"  |xargs -i rm {}
find  $L2P_SENTDIR   -type f  -amin +240 -ls |grep "OSDPD"  
find  $L2P_SENTDIR   -type f  -amin +240     |grep "OSDPD"  |xargs -i rm {}
find  $L2P_SENTDIR   -type f  -mtime +0      |grep "OSDPD"  |xargs -i rm {}


### FR-20060928-GOES12-OSDPD-L2P-GOES12_North_1815Z-v01.xml
# Area Data Reformatted (incase proc doesn't take care of it)
#echo " Cleaning  $L2PData/netcdf_input"
echo " Cleaning  $L2P_OLDIN"
find  $L2P_OLDIN  -type f  -mtime +0 -ls |grep "L2P.0" 
find  $L2P_OLDIN  -type f  -mtime +0     |grep "L2P.0"  |xargs -i rm {}
find  $L2P_OLDIN  -type f  -amin +200    |grep "L2P.0" 
find  $L2P_OLDIN  -type f  -amin +200    |grep "L2P.0"  |xargs -i rm  {}
#
#-----------------------------------------------------------------
echo "End $0 at `date`"
