#!/bin/bash
#
#####################################################################
#
# Program Name: get_buoy_ddspull.sh
#
# Purpose: Get buoy data for matchups vs goessst
#    -- direct from dds pull directory for F0243
#   the previous hour's file if running earlier in the hour
#
# Usage: get_buoy_ddspull.sh
#
# Change history:
#    2014-07-14  R Potash - Initial version
#                -- modified from get_buoy_dist5.sh
#
#####################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
export SCRIPTNAME=$( basename $0 )
LOGDIR=$HOME/mcidas/logs
MCDATDIR=$HOME/mcidas/data


# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#         daily log file
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $SCRIPTNAME  -l logfile_name \n";;
           esac
done

# set remote server
#--------------------------
remoteServer="10.144.3.7"     # DDS
remoteDir="pull"

#-----------------------------------------------------------------------
cymd=$( date -u  -d'50 minutes ago'   +%Y%m%d )
yyyyddd=$( date -u  -d'50 minutes ago'   +%Y%j )
hour=$( date -u  -d'50 minutes ago'   +%H )

remoteName=buoysst.ascii_${hour}.${cymd}
localNameLong=buoysst.${hour}.${yyyyddd}
localNameShort=buoysst.${hour}


echo  "=============================================================="
echo " Start $scriptname at $(date) "

echo "          cymd = $cymd "
echo "       yyyyddd = $yyyyddd "
echo "          hour = $hour "
echo "     remoteDir = $remoteDir "
echo "    remoteName = $remoteName "
echo "     localName = $localNameLong "
echo "     localName = $localNameShort "

# go to mcidas data directory
#------------------------------
cd $MCDATDIR

echo "Does buoy file already exist?"
pwd
ls -l $localNameShort

ls -l $localNameLong

[ -s $localNameLong ] && exit

# fetch the data
#------------------------------------------

echo "ftptime  $remoteServer  << EOF   2>&1"
echo "     cd $remoteDir"
echo "     get $remoteName $localNameLong"
echo "     quit"
echo "EOF"

echo "$HOME/mcidas/bin/ftptime  $remoteServer  << EOF   2>&1"
$HOME/mcidas/bin/ftptime  $remoteServer  << EOF   2>&1
     pwd
     ls
     cd $remoteDir
     pwd
     ls     
     get $remoteName $localNameLong
     quit
EOF

rc1=$?
ls -l $localNameLong 
rc2=$?
[ $rc1 -eq 0 ]  && [ $rc2 -eq 0 ]  &&  echo "Buoy data fetching successfuly"  || echo "Buoy data fetching failed"


# clean old file
#------------------
#rm -f $localNameShort 

[ -s $localNameLong ] && cp $localNameLong $localNameShort
ls -l $localNameShort

##find .  -type f -mmin +4320 | grep buoysst |xargs -i rm {}

echo "End $scriptname at `date -u`\n"

